@@ -58,7 +58,7 @@
 #'
 #' # call build_package to run the "foo.Rmd" processing and
 #' # build a data package.
-#' package_build(file.path(tempdir(), pname))
+#' package_build(file.path(tempdir(), pname), install = FALSE)
 #'
 #' # "install" the data package
 #' devtools::load_all(file.path(tempdir(), pname))
@@ -345,7 +345,8 @@ DataPackageR <- function(arg = NULL, deps = TRUE) {
           pkg_description,
           new_data_digest
         )
-        .update_news_md(updated_version$new_data_digest[["DataVersion"]], interact = getOption("DataPackageR_interact",interactive()))
+        .update_news_md(updated_version$new_data_digest[["DataVersion"]],
+          interact = getOption("DataPackageR_interact", interactive()))
         pkg_description <- updated_version$pkg_description
         new_data_digest <- updated_version$new_data_digest
         can_write <- TRUE
@@ -387,7 +388,8 @@ DataPackageR <- function(arg = NULL, deps = TRUE) {
           pkg_description,
           new_data_digest
         )
-        .update_news_md(updated_version$new_data_digest[["DataVersion"]], interact = getOption("DataPackageR_interact",interactive()))
+        .update_news_md(updated_version$new_data_digest[["DataVersion"]],
+          interact = getOption("DataPackageR_interact", interactive()))
         pkg_description <- updated_version$pkg_description
         new_data_digest <- updated_version$new_data_digest
         can_write <- TRUE
@@ -403,7 +405,9 @@ DataPackageR <- function(arg = NULL, deps = TRUE) {
         do_documentation <- TRUE
       }
     } else {
-      .update_news_md(new_data_digest[["DataVersion"]], interact = getOption("DataPackageR_interact",interactive()))
+      .update_news_md(new_data_digest[["DataVersion"]],
+        interact = getOption("DataPackageR_interact",
+                             interactive()))
       .save_data(new_data_digest,
         pkg_description,
         ls(dataenv),
